##############################################################################
#
#    Accounting periods, for Odoo
#    Copyright (C) 2018 XCG Consulting <http://odoo.consulting>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from odoo import fields
from odoo import models


class AccountFiscalyear(models.Model):
    """Account fiscal year defined an accounting year.
    """

    _name = 'account.fiscalyear'
    _description = 'Fiscal year'

    code = fields.Char(
        string='Code',
        help='Unique code of this fiscal year.',
        index=True,
        required=True,
    )

    company_id = fields.Many2one(
        comodel_name='res.company',
        string='Company',
        default=lambda rec: rec.env.user.company_id,
        help='The company the fiscal year is in.',
        required=True,
    )

    name = fields.Char(
        string='Name',
        help='Displayed name of this fiscal year.',
        required=True,
    )

    period_ids = fields.One2many(
        comodel_name='account.period',
        inverse_name='fiscalyear_id',
        string='Periods',
        help='The periods inside this fiscal year.',
    )

    _sql_constraints = [
        ('unique_code', 'UNIQUE(code)', 'The code must be unique.'),
    ]
