##############################################################################
#
#    Accounting periods, for Odoo
#    Copyright (C) 2018 XCG Consulting <http://odoo.consulting>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as
#    published by the Free Software Foundation, either version 3 of the
#    License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from odoo import fields
from odoo import models


class AccountPeriod(models.Model):
    """Account period defined an accounting period.

    This module aims to recreate the same behaviour than the account.period
    model in odoo previous versions.
    """

    _name = 'account.period'
    _description = 'Accounting period'

    code = fields.Char(
        string='Code',
        help='Unique code of this period.',
        index=True,
        required=True,
    )

    company_id = fields.Many2one(
        related=('fiscalyear_id', 'company_id'),
        comodel_name='res.company',
        string='Company',
        help='The company the fiscal year is in.',
        readonly=True,
        store=True,
    )

    date_cutoff = fields.Date(
        string='Cut-off date',
        help=(
            'Optional cut-off date which helps force transaction dates and '
            'this period for a few days after the end of this period.'
        ),
    )

    date_start = fields.Date(
        string='Start',
        help='When this period starts.',
        required=True,
    )

    date_stop = fields.Date(
        string='End',
        help='When this period ends.',
        required=True,
    )

    fiscalyear_id = fields.Many2one(
        comodel_name='account.fiscalyear',
        string='Fiscal year',
        help='The fiscal year this period is in.',
        ondelete='cascade',
        required=True,
    )

    name = fields.Char(
        string='Name',
        help='Displayed name of this period.',
        required=True,
    )

    state = fields.Selection(
        selection=[
            ('draft', 'Open'),
            ('done', 'Closed'),
        ],
        string='State',
        default='draft',
        readonly=True,
        required=True,
    )

    _sql_constraints = [
        ('unique_code', 'UNIQUE(code)', 'The code must be unique.'),
    ]
